import { Ask, Bid, BidShares } from "./types";
import { BigNumber, BigNumberish } from "@ethersproject/bignumber";
import { Provider } from "@ethersproject/providers";
import { Signer } from "@ethersproject/abstract-signer";
import { SpaceExchange, Space } from "@motif-foundation/asset/dist/typechain";
export declare class MotifSpace {
    chainId: number;
    spaceAddress: string;
    spaceExchangeAddress: string;
    signerOrProvider: Signer | Provider;
    space: Space;
    spaceExchange: SpaceExchange;
    readOnly: boolean;
    constructor(signerOrProvider: Signer | Provider, chainId: number);
    /*********************
     * Space Read Methods
     *********************
     */
    fetchContentHash(spaceId: BigNumberish): Promise<string>;
    fetchMetadataHash(spaceId: BigNumberish): Promise<string>;
    fetchContentURI(spaceId: BigNumberish): Promise<string>;
    fetchMetadataURI(spaceId: BigNumberish): Promise<string>;
    fetchIsPublic(spaceId: BigNumberish): Promise<boolean>;
    fetchLands(spaceId: BigNumberish): Promise<Array<BigNumberish>>;
    fetchCreator(spaceId: BigNumberish): Promise<string>;
    fetchCurrentBidShares(spaceId: BigNumberish): Promise<BidShares>;
    fetchCurrentAsk(spaceId: BigNumberish): Promise<Ask>;
    fetchCurrentBidForBidder(spaceId: BigNumberish, bidder: string): Promise<Bid>;
    fetchPermitNonce(address: string, spaceId: BigNumberish): Promise<BigNumber>;
    fetchMintWithSigNonce(address: string): Promise<BigNumber>;
}
