"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MotifSpace = void 0;
const tslib_1 = require("tslib");
const abstract_signer_1 = require("@ethersproject/abstract-signer");
const typechain_1 = require("@motif-foundation/asset/dist/typechain");
const addresses_1 = require("./addresses");
const utils_1 = require("./utils");
class MotifSpace {
    constructor(signerOrProvider, chainId) {
        if (abstract_signer_1.Signer.isSigner(signerOrProvider)) {
            this.readOnly = false;
        }
        else {
            this.readOnly = true;
        }
        this.signerOrProvider = signerOrProvider;
        this.chainId = chainId;
        const network = (0, utils_1.chainIdToNetworkName)(chainId);
        this.spaceAddress = addresses_1.addresses[network].space;
        this.spaceExchangeAddress = addresses_1.addresses[network].spaceExchange;
        this.space = typechain_1.SpaceFactory.connect(this.spaceAddress, signerOrProvider);
        this.spaceExchange = typechain_1.SpaceExchangeFactory.connect(this.spaceExchangeAddress, signerOrProvider);
    }
    /*********************
     * Space Read Methods
     *********************
     */
    fetchContentHash(spaceId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.space.tokenContentHashes(spaceId);
        });
    }
    fetchMetadataHash(spaceId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.space.tokenMetadataHashes(spaceId);
        });
    }
    fetchContentURI(spaceId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.space.tokenURI(spaceId);
        });
    }
    fetchMetadataURI(spaceId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.space.tokenMetadataURI(spaceId);
        });
    }
    fetchIsPublic(spaceId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.space.isPublic(spaceId);
        });
    }
    fetchLands(spaceId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.space.lands(spaceId);
        });
    }
    fetchCreator(spaceId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.space.tokenCreators(spaceId);
        });
    }
    fetchCurrentBidShares(spaceId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.spaceExchange.bidSharesForToken(spaceId);
        });
    }
    fetchCurrentAsk(spaceId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.spaceExchange.currentAskForToken(spaceId);
        });
    }
    fetchCurrentBidForBidder(spaceId, bidder) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.spaceExchange.bidForTokenBidder(spaceId, bidder);
        });
    }
    fetchPermitNonce(address, spaceId) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.space.permitNonces(address, spaceId);
        });
    }
    fetchMintWithSigNonce(address) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
            return this.space.mintWithSigNonces(address);
        });
    }
}
exports.MotifSpace = MotifSpace;
//# sourceMappingURL=MotifSpace.js.map